@@ -1,5 +1,5 @@
-from .utils import Command
 from .functions import *
+from .utils import Command
 
 commands = [
     Command(("水平翻转", "左翻", "右翻"), flip_horizontal),
@@ -16,11 +16,15 @@ commands = [
     Command(("像素化",), pixelate),
     Command(("颜色滤镜",), color_mask),
     Command(("纯色图",), color_image),
+    Command(("渐变图",), gradient_image),
     Command(("gif倒放", "倒放"), gif_reverse),
     Command(("gif正放倒放", "正放倒放"), gif_obverse_reverse),
     Command(("gif变速",), gif_change_fps),
     Command(("gif分解",), gif_split),
+    Command(("gif合成",), gif_join),
     Command(("四宫格",), four_grid),
     Command(("九宫格",), nine_grid),
+    Command(("横向拼接",), horizontal_join),
+    Command(("纵向拼接",), vertical_join),
     Command(("文字转图",), t2p),
 ]
