@@ -1,15 +1,17 @@
+import math
 import re
 from io import BytesIO
 from typing import List, Optional
-from PIL.Image import Image as IMG
-from PIL.ImageColor import colormap
-from PIL import Image, ImageFilter, ImageOps
 
-from nonebot_plugin_imageutils import BuildImage, text2image
+from PIL import Image, ImageFilter, ImageOps
+from PIL.ImageColor import colormap
+from pil_utils import BuildImage, text2image
+from pil_utils.gradient import ColorStop, LinearGradient
+from pil_utils.types import ColorType
 
 from .color_table import color_table
-from .depends import Arg, Img, NoArg
-from .utils import save_gif, make_jpg_or_gif, Maker, get_avg_duration, split_gif
+from .depends import Arg, Args, Img, Imgs, NoArg
+from .utils import Maker, get_avg_duration, make_jpg_or_gif, save_gif, split_gif
 
 colors = "|".join(colormap.keys())
 color_pattern_str = rf"#[a-fA-F0-9]{{6}}|{colors}"
@@ -133,7 +135,7 @@ def color_mask(img: BuildImage = Img(), arg: str = Arg()):
     elif arg in color_table:
         color = color_table[arg]
     else:
-        return "请使用正确的颜色格式，如：#66ccff、red、红色、102 204 255"
+        return "请使用正确的颜色格式，如：#66ccff、red、红色、102,204,255"
     return make_jpg_or_gif(img, lambda img: img.color_mask(color))
 
 
@@ -145,10 +147,56 @@ def color_image(arg: str = Arg()):
     elif arg in color_table:
         color = color_table[arg]
     else:
-        return "请使用正确的颜色格式，如：#66ccff、red、红色、102 204 255"
+        return "请使用正确的颜色格式，如：#66ccff、red、红色、102,204,255"
     return BuildImage.new("RGB", (500, 500), color).save_jpg()
 
 
+def gradient_image(args: List[str] = Args()):
+    if not args:
+        return
+    angle = 0
+    if args[0] in ["上下", "竖直"]:
+        angle = 90
+        args = args[1:]
+    elif args[0] in ["左右", "水平"]:
+        angle = 0
+        args = args[1:]
+    elif args[0].isdigit():
+        angle = int(args[0])
+        args = args[1:]
+    if not args:
+        return
+
+    colors: List[ColorType] = []
+    for arg in args:
+        if re.fullmatch(color_pattern_str, arg):
+            color = arg
+        elif match := re.fullmatch(color_pattern_num, arg):
+            color = tuple(map(int, match.groups()))
+        elif arg in color_table:
+            color = color_table[arg]
+        else:
+            return "请使用正确的颜色格式，如：#66ccff、red、红色、102,204,255"
+        colors.append(color)
+
+    img_w = 500
+    img_h = 500
+    angle *= math.pi / 180
+    if math.sqrt(img_w**2 + img_h**2) * math.cos(angle) <= img_w:
+        dy = img_h / 2
+        dx = dy / math.tan(angle)
+    else:
+        dx = img_w / 2
+        dy = dx * math.tan(angle)
+
+    gradient = LinearGradient(
+        (img_w / 2 - dx, img_h / 2 - dy, img_w / 2 + dx, img_h / 2 + dy),
+        [ColorStop(i / (len(colors) - 1), color) for i, color in enumerate(colors)],
+    )
+    img = gradient.create_image((img_w, img_h))
+    return BuildImage(img).save_jpg()
+
+
 def gif_reverse(img: BuildImage = Img(), arg=NoArg()):
     image = img.image
     if getattr(image, "is_animated", False):
@@ -190,6 +238,25 @@ def gif_split(img: BuildImage = Img(), arg=NoArg()):
         return [BuildImage(frame).save_png() for frame in frames]
 
 
+def gif_join(imgs: List[BuildImage] = Imgs(), arg: str = Arg()):
+    if not arg:
+        duration = 100
+    elif arg.isdigit():
+        duration = int(arg)
+    else:
+        return
+
+    if not imgs:
+        return
+    if len(imgs) < 2:
+        return "gif合成至少需要2张图片"
+
+    max_w = max([img.width for img in imgs])
+    max_h = max([img.height for img in imgs])
+    frames = [img.resize_canvas((max_w, max_h)).image for img in imgs]
+    return save_gif(frames, duration / 1000)
+
+
 def four_grid(img: BuildImage = Img(), arg=NoArg()):
     img = img.square()
     l = img.width // 2
@@ -226,5 +293,41 @@ def nine_grid(img: BuildImage = Img(), arg=NoArg()):
     return output
 
 
+def horizontal_join(imgs: List[BuildImage] = Imgs(), arg=NoArg()):
+    if not imgs:
+        return
+    if len(imgs) < 2:
+        return "图片拼接至少需要2张图片"
+
+    spacing = 10
+    img_h = min([img.height for img in imgs])
+    imgs = [img.resize((img.width * img_h // img.height, img_h)) for img in imgs]
+    img_w = sum([img.width for img in imgs]) + spacing * (len(imgs) - 1)
+    frame = BuildImage.new("RGB", (img_w, img_h), "white")
+    x = 0
+    for img in imgs:
+        frame.paste(img, (x, 0))
+        x += img.width + spacing
+    return frame.save_jpg()
+
+
+def vertical_join(imgs: List[BuildImage] = Imgs(), arg=NoArg()):
+    if not imgs:
+        return
+    if len(imgs) < 2:
+        return "图片拼接至少需要2张图片"
+
+    spacing = 10
+    img_w = min([img.width for img in imgs])
+    imgs = [img.resize((img_w, img.height * img_w // img.width)) for img in imgs]
+    img_h = sum([img.height for img in imgs]) + spacing * (len(imgs) - 1)
+    frame = BuildImage.new("RGB", (img_w, img_h), "white")
+    y = 0
+    for img in imgs:
+        frame.paste(img, (0, y))
+        y += img.height + spacing
+    return frame.save_jpg()
+
+
 def t2p(arg: str = Arg()):
     return BuildImage(text2image(arg, padding=(20, 20), max_width=1000)).save_png()
